@@ -384,8 +384,19 @@ class SQLVisitor(SQLParserVisitor):
 
         # 连接参数信息
         if ctx.connectParameter() is not None:
-            result, script, hint, code, message = self.visit(ctx.connectParameter())
-            parsedObject.update(result)
+            parameters = []
+            for parameter in ctx.connectParameter():
+                result, code, message = self.visit(parameter)
+                if code != 0:
+                    errorCode = code
+                    errorMsg = message
+                    return parsedObject, errorCode, errorMsg
+                parameters.append(result)
+            parsedObject.update(
+                {
+                    "parameters": parameters
+                }
+            )
 
         # 获取错误代码
         errorCode = 0
@@ -400,11 +411,11 @@ class SQLVisitor(SQLParserVisitor):
         parsedObject = {}
 
         if ctx.connectParameterName() is not None:
-            result, script, hint, code, message = self.visit(ctx.connectParameterName())
+            result, code, message = self.visit(ctx.connectParameterName())
             parsedObject.update(result)
 
         if ctx.connectParameterValue() is not None:
-            result, script, hint, code, message = self.visit(ctx.connectParameterValue())
+            result, code, message = self.visit(ctx.connectParameterValue())
             parsedObject.update(result)
 
         # 获取错误代码
@@ -619,15 +630,37 @@ class SQLVisitor(SQLParserVisitor):
             parsedObject.update({"action": "disconnect"})
         if ctx.SSH_EXECUTE() is not None:
             parsedObject.update({"action": "execute"})
+            parsedObject.update({"command": ""})
             commands = []
             for expression in ctx.SSH_EXPRESSION():
                 commands.append(str(expression.getText()))
-            commond = str(" ".join(commands)).strip()
-            if commond.startswith('"') and commond.endswith('"'):
-                commond = commond[1:-1]
-            if commond.startswith("'") and commond.endswith("'"):
-                commond = commond[1:-1]
-            parsedObject.update({"command": commond})
+            command = str(" ".join(commands)).strip()
+            if (
+                    (command.startswith('"') and not command.endswith('"')) or
+                    (command.startswith("'") and not command.endswith("'"))
+            ):
+                # 括号不闭合
+                self.isFinished = False
+                self.parsedObject = parsedObject
+                self.errorCode = 1
+                self.errorMsg = "Missing <EOF> un-closed qutote string."
+                return
+            if command.startswith('"') and command.endswith('"'):
+                command = command[1:-1]
+            if command.startswith("'") and command.endswith("'"):
+                command = command[1:-1]
+            pairQuote = True
+            for quoteChar in ['"', "'"]:
+                for char in command:
+                    if char == quoteChar:
+                        pairQuote = not pairQuote
+                if not pairQuote:
+                    self.isFinished = False
+                    self.parsedObject = parsedObject
+                    self.errorCode = 1
+                    self.errorMsg = "Missing <EOF> un-closed qutote string."
+                    return
+            parsedObject.update({"command": command})
         if ctx.SSH_CONNECT() is not None:
             parsedObject.update({"action": "connect"})
             parsedObject.update({"host": str(ctx.SSH_EXPRESSION()[0].getText())})
@@ -1360,25 +1393,6 @@ class SQLVisitor(SQLParserVisitor):
         self.errorCode = errorCode
         self.errorMsg = errorMsg
 
-    def visitSqlCommitRollback(self, ctx: SQLParser.SqlCommitRollbackContext):
-        parsedObject = {}
-        if ctx.SQL_COMMIT() is not None:
-            parsedObject = {'name': 'COMMIT', 'statement': ctx.SQL_COMMIT().getText()}
-        if ctx.SQL_ROLLBACK() is not None:
-            parsedObject = {'name': 'ROLLBACK', 'statement': ctx.SQL_ROLLBACK().getText()}
-
-        # 获取错误代码
-        errorCode = 0
-        errorMsg = None
-        if ctx.exception is not None:
-            errorCode = -1
-            errorMsg = ctx.exception.message
-
-        # 如果SQL没有结尾，要返回没有结尾的标志
-        self.parsedObject = parsedObject
-        self.errorCode = errorCode
-        self.errorMsg = errorMsg
-
     def visitSqlDeclare(self, ctx: SQLParser.SqlDeclareContext):
         start, end = self.getSourceInterval(ctx)
         tokens = ctx.parser._input.tokens[start:end + 1]
